public inbox for devel@edk2.groups.io
 help / color / mirror / Atom feed
From: Gary Lin <glin@suse.com>
To: edk2-devel@lists.01.org
Cc: Liming Gao <liming.gao@intel.com>
Subject: [PATCH 07/33] EdkCompatibilityPkg: Fix typos in comments
Date: Wed, 19 Oct 2016 15:01:12 +0800	[thread overview]
Message-ID: <20161019070138.16424-8-glin@suse.com> (raw)
In-Reply-To: <20161019070138.16424-1-glin@suse.com>

- excute -> execute
- Pacakges -> Packages
- successfull -> successfully
- outputed -> outputted
- triggerred -> triggered
- specifiecd -> specified
- hexidecimal -> hexadecimal
- Arrary -> Array
- Pointion -> Position
- paramter -> parameter
- stardard -> standard
- perodically -> periodically
- dependecy -> dependency
- evauated -> evaluated
- availible -> available
- boundry -> boundary
- discontiguous -> discontinuous

Cc: Liming Gao <liming.gao@intel.com>
Contributed-under: TianoCore Contribution Agreement 1.0
Signed-off-by: Gary Lin <glin@suse.com>
---
 EdkCompatibilityPkg/Compatibility/BootScriptSaveOnS3SaveStateThunk/ScriptSave.c                                    |  4 ++--
 EdkCompatibilityPkg/Compatibility/FrameworkHiiOnUefiHiiThunk/HiiDatabase.h                                         |  4 ++--
 EdkCompatibilityPkg/Compatibility/FrameworkHiiOnUefiHiiThunk/Package.c                                             |  6 +++---
 EdkCompatibilityPkg/Compatibility/FrameworkHiiOnUefiHiiThunk/Utility.c                                             |  2 +-
 EdkCompatibilityPkg/Compatibility/FrameworkHiiOnUefiHiiThunk/Utility.h                                             |  2 +-
 EdkCompatibilityPkg/Compatibility/MpServicesOnFrameworkMpServicesThunk/MpServicesOnFrameworkMpServicesThunk.c      |  2 +-
 EdkCompatibilityPkg/Compatibility/MpServicesOnFrameworkMpServicesThunk/MpServicesOnFrameworkMpServicesThunk.h      |  2 +-
 EdkCompatibilityPkg/Foundation/Cpu/Pentium/Include/CpuIA32.h                                                       |  2 +-
 EdkCompatibilityPkg/Foundation/Efi/Include/EfiTypes.h                                                              |  4 ++--
 EdkCompatibilityPkg/Foundation/Efi/Protocol/HiiDatabase/HiiDatabase.h                                              |  4 ++--
 EdkCompatibilityPkg/Foundation/Framework/Include/EfiDependency.h                                                   |  4 ++--
 EdkCompatibilityPkg/Foundation/Framework/Protocol/LegacyBios/LegacyBios.h                                          |  2 +-
 EdkCompatibilityPkg/Foundation/Library/CustomizedDecompress/CustomizedDecompress.c                                 |  2 +-
 EdkCompatibilityPkg/Foundation/Library/CustomizedDecompress/CustomizedDecompress.h                                 |  2 +-
 EdkCompatibilityPkg/Foundation/Library/Dxe/Include/Ia32/CpuFuncs.h                                                 |  2 +-
 EdkCompatibilityPkg/Foundation/Library/Dxe/Include/X64/CpuFuncs.h                                                  |  2 +-
 EdkCompatibilityPkg/Foundation/Library/Dxe/UefiEfiIfrSupportLib/UefiIfrForm.c                                      |  2 +-
 EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Include/Library/EdkIIGluePrintLib.h                            |  2 +-
 EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Include/Library/EdkIIGlueUefiDecompressLib.h                   |  2 +-
 EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Library/BaseUefiDecompressLib/BaseUefiDecompressLib.c          | 10 +++++-----
 EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Library/BaseUefiDecompressLib/BaseUefiDecompressLibInternals.h |  2 +-
 EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Library/DxeIoLibCpuIo/DxeCpuIoLibInternal.h                    |  2 +-
 EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Library/DxeIoLibCpuIo/IoLib.c                                  |  2 +-
 EdkCompatibilityPkg/Foundation/Library/Pei/PeiLib/Decompress.c                                                     |  6 +++---
 EdkCompatibilityPkg/Sample/Platform/Nt32/Ppi/NtAutoScan/NtAutoScan.h                                               |  2 +-
 EdkCompatibilityPkg/Sample/Tools/Source/Common/Decompress.c                                                        |  6 +++---
 EdkCompatibilityPkg/Sample/Tools/Source/Common/Decompress.h                                                        |  4 ++--
 EdkCompatibilityPkg/Sample/Tools/Source/Common/EfiCustomizedCompress.h                                             |  2 +-
 EdkCompatibilityPkg/Sample/Tools/Source/CustomizedCompress/CustomizedCompress.c                                    |  2 +-
 EdkCompatibilityPkg/Sample/Tools/Source/GenDepex/GenDepex.c                                                        |  2 +-
 EdkCompatibilityPkg/Sample/Tools/Source/GenFfsFile/GenFfsFile.c                                                    |  2 +-
 31 files changed, 47 insertions(+), 47 deletions(-)

diff --git a/EdkCompatibilityPkg/Compatibility/BootScriptSaveOnS3SaveStateThunk/ScriptSave.c b/EdkCompatibilityPkg/Compatibility/BootScriptSaveOnS3SaveStateThunk/ScriptSave.c
index 0bc2f75..a3503a5 100644
--- a/EdkCompatibilityPkg/Compatibility/BootScriptSaveOnS3SaveStateThunk/ScriptSave.c
+++ b/EdkCompatibilityPkg/Compatibility/BootScriptSaveOnS3SaveStateThunk/ScriptSave.c
@@ -358,7 +358,7 @@ BootScriptPciCfg2ReadWrite (
                           );
 }
 /**
-  Internal function to add smbus excute opcode to the table.
+  Internal function to add smbus execute opcode to the table.
 
   @param  Marker                The variable argument list to get the opcode
                                 and associated attributes.
@@ -913,7 +913,7 @@ InitializeScriptSaveOnS3SaveState (
     ASSERT_EFI_ERROR (Status);
     ImageContext.ImageAddress = (PHYSICAL_ADDRESS)(UINTN)MemoryAddress;
     //
-    // Align buffer on section boundry
+    // Align buffer on section boundary
     //
     ImageContext.ImageAddress += ImageContext.SectionAlignment - 1;
     ImageContext.ImageAddress &= ~(ImageContext.SectionAlignment - 1);
diff --git a/EdkCompatibilityPkg/Compatibility/FrameworkHiiOnUefiHiiThunk/HiiDatabase.h b/EdkCompatibilityPkg/Compatibility/FrameworkHiiOnUefiHiiThunk/HiiDatabase.h
index d86572a..c736990 100644
--- a/EdkCompatibilityPkg/Compatibility/FrameworkHiiOnUefiHiiThunk/HiiDatabase.h
+++ b/EdkCompatibilityPkg/Compatibility/FrameworkHiiOnUefiHiiThunk/HiiDatabase.h
@@ -249,7 +249,7 @@ extern BOOLEAN                                    mInFrameworkUpdatePakcage;
   @param Packages  Pointer of HII packages.
   @param Handle    Handle value to be returned.
 
-  @retval EFI_SUCCESS           Pacakges has added to HII database successfully.
+  @retval EFI_SUCCESS           Packages has added to HII database successfully.
   @retval EFI_INVALID_PARAMETER If Handle or Packages is NULL.
 
 **/
@@ -268,7 +268,7 @@ HiiNewPack (
   @param This      Pointer of Frameowk HII protocol instance.
   @param Handle    Handle value to be removed.
 
-  @retval EFI_SUCCESS           Pacakges has added to HII database successfully.
+  @retval EFI_SUCCESS           Packages has added to HII database successfully.
   @retval EFI_INVALID_PARAMETER If Handle or Packages is NULL.
 
 **/
diff --git a/EdkCompatibilityPkg/Compatibility/FrameworkHiiOnUefiHiiThunk/Package.c b/EdkCompatibilityPkg/Compatibility/FrameworkHiiOnUefiHiiThunk/Package.c
index 2d3031a..caa5cf8 100644
--- a/EdkCompatibilityPkg/Compatibility/FrameworkHiiOnUefiHiiThunk/Package.c
+++ b/EdkCompatibilityPkg/Compatibility/FrameworkHiiOnUefiHiiThunk/Package.c
@@ -455,7 +455,7 @@ FindStringPackAndUpdatePackListWithOnlyIfrPack (
   @param Handle                       On output, a FRAMEWORK_EFI_HII_HANDLE number is
                                       returned.
 
-  @retval EFI_SUCCESS                 The Package List is registered successfull in 
+  @retval EFI_SUCCESS                 The Package List is registered successfully in
                                       the database.
   @retval EFI_UNSUPPORTED             The number of IFR package in the package list
                                       is greater than 1.
@@ -644,7 +644,7 @@ Done:
   @param Packages  Pointer of HII packages.
   @param Handle    Handle value to be returned.
 
-  @retval EFI_SUCCESS           Pacakges has added to HII database successfully.
+  @retval EFI_SUCCESS           Packages has added to HII database successfully.
   @retval EFI_INVALID_PARAMETER If Handle or Packages is NULL.
 
 **/
@@ -701,7 +701,7 @@ HiiNewPack (
   @param This      Pointer of Frameowk HII protocol instance.
   @param Handle    Handle value to be removed.
 
-  @retval EFI_SUCCESS           Pacakges has added to HII database successfully.
+  @retval EFI_SUCCESS           Packages has added to HII database successfully.
   @retval EFI_INVALID_PARAMETER If Handle or Packages is NULL.
 
 **/
diff --git a/EdkCompatibilityPkg/Compatibility/FrameworkHiiOnUefiHiiThunk/Utility.c b/EdkCompatibilityPkg/Compatibility/FrameworkHiiOnUefiHiiThunk/Utility.c
index d269b8e..93cd710 100644
--- a/EdkCompatibilityPkg/Compatibility/FrameworkHiiOnUefiHiiThunk/Utility.c
+++ b/EdkCompatibilityPkg/Compatibility/FrameworkHiiOnUefiHiiThunk/Utility.c
@@ -53,7 +53,7 @@ CONST CHAR16 FrameworkReservedVarstoreName[] = FRAMEWORK_RESERVED_VARSTORE_NAME;
   @param HandleBuffer         On output, an array of EFI_HII_HANDLE  instances returned.
                               The caller is responcible to free this pointer allocated.
 
-  @retval EFI_SUCCESS           The matching handles are outputed successfully.
+  @retval EFI_SUCCESS           The matching handles are outputted successfully.
                                 HandleBufferLength is updated with the actual length.
   @retval EFI_OUT_OF_RESOURCES  Not enough resource to complete the operation.
   @retval EFI_NOT_FOUND         No matching handle could not be found in database.
diff --git a/EdkCompatibilityPkg/Compatibility/FrameworkHiiOnUefiHiiThunk/Utility.h b/EdkCompatibilityPkg/Compatibility/FrameworkHiiOnUefiHiiThunk/Utility.h
index 4f453f1..551c4bf 100644
--- a/EdkCompatibilityPkg/Compatibility/FrameworkHiiOnUefiHiiThunk/Utility.h
+++ b/EdkCompatibilityPkg/Compatibility/FrameworkHiiOnUefiHiiThunk/Utility.h
@@ -48,7 +48,7 @@ WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
   @param HandleBuffer         On output, an array of EFI_HII_HANDLE  instances returned.
                               The caller is responcible to free this pointer allocated.
 
-  @retval EFI_SUCCESS           The matching handles are outputed successfully.
+  @retval EFI_SUCCESS           The matching handles are outputted successfully.
                                 HandleBufferLength is updated with the actual length.
   @retval EFI_OUT_OF_RESOURCES  Not enough resource to complete the operation.
   @retval EFI_NOT_FOUND         No matching handle could not be found in database.
diff --git a/EdkCompatibilityPkg/Compatibility/MpServicesOnFrameworkMpServicesThunk/MpServicesOnFrameworkMpServicesThunk.c b/EdkCompatibilityPkg/Compatibility/MpServicesOnFrameworkMpServicesThunk/MpServicesOnFrameworkMpServicesThunk.c
index eb281d6..73c89a1 100644
--- a/EdkCompatibilityPkg/Compatibility/MpServicesOnFrameworkMpServicesThunk/MpServicesOnFrameworkMpServicesThunk.c
+++ b/EdkCompatibilityPkg/Compatibility/MpServicesOnFrameworkMpServicesThunk/MpServicesOnFrameworkMpServicesThunk.c
@@ -747,7 +747,7 @@ WhoAmI (
 /**
   Checks APs' status periodically.
 
-  This function is triggerred by timer perodically to check the
+  This function is triggered by timer periodically to check the
   state of APs for StartupAllAPs() and StartupThisAP() executed
   in non-blocking mode.
 
diff --git a/EdkCompatibilityPkg/Compatibility/MpServicesOnFrameworkMpServicesThunk/MpServicesOnFrameworkMpServicesThunk.h b/EdkCompatibilityPkg/Compatibility/MpServicesOnFrameworkMpServicesThunk/MpServicesOnFrameworkMpServicesThunk.h
index 7f9d107..1374968 100644
--- a/EdkCompatibilityPkg/Compatibility/MpServicesOnFrameworkMpServicesThunk/MpServicesOnFrameworkMpServicesThunk.h
+++ b/EdkCompatibilityPkg/Compatibility/MpServicesOnFrameworkMpServicesThunk/MpServicesOnFrameworkMpServicesThunk.h
@@ -340,7 +340,7 @@ WhoAmI (
 /**
   Checks APs' status periodically.
 
-  This function is triggerred by timer perodically to check the
+  This function is triggered by timer periodically to check the
   state of APs for StartupAllAPs() and StartupThisAP() executed
   in non-blocking mode.
 
diff --git a/EdkCompatibilityPkg/Foundation/Cpu/Pentium/Include/CpuIA32.h b/EdkCompatibilityPkg/Foundation/Cpu/Pentium/Include/CpuIA32.h
index 746b4c0..b0ec374 100644
--- a/EdkCompatibilityPkg/Foundation/Cpu/Pentium/Include/CpuIA32.h
+++ b/EdkCompatibilityPkg/Foundation/Cpu/Pentium/Include/CpuIA32.h
@@ -187,7 +187,7 @@ EfiCpuid (
 
 /*++                                                                                                                          
 Routine Description:                                                
-  Get the Cpu info by excute the CPUID instruction
+  Get the Cpu info by execute the CPUID instruction
 Arguments:                
    RegisterInEax: -The input value to put into register EAX
    Regs:          -The Output value                      
diff --git a/EdkCompatibilityPkg/Foundation/Efi/Include/EfiTypes.h b/EdkCompatibilityPkg/Foundation/Efi/Include/EfiTypes.h
index 026854a..81d3b00 100644
--- a/EdkCompatibilityPkg/Foundation/Efi/Include/EfiTypes.h
+++ b/EdkCompatibilityPkg/Foundation/Efi/Include/EfiTypes.h
@@ -262,12 +262,12 @@ typedef struct {
 #define EFI_PAGES_TO_SIZE(a)   ( (a) << EFI_PAGE_SHIFT)
 
 //
-//  ALIGN_POINTER - aligns a pointer to the lowest boundry
+//  ALIGN_POINTER - aligns a pointer to the lowest boundary
 //
 #define ALIGN_POINTER(p, s) ((VOID *) (p + ((s - ((UINTN) p)) & (s - 1))))
 
 //
-//  ALIGN_VARIABLE - aligns a variable up to the next natural boundry for int size of a processor
+//  ALIGN_VARIABLE - aligns a variable up to the next natural boundary for int size of a processor
 //
 #define ALIGN_VARIABLE(Value, Adjustment) \
   (UINTN) Adjustment = 0; \
diff --git a/EdkCompatibilityPkg/Foundation/Efi/Protocol/HiiDatabase/HiiDatabase.h b/EdkCompatibilityPkg/Foundation/Efi/Protocol/HiiDatabase/HiiDatabase.h
index b319aae..0db81dd 100644
--- a/EdkCompatibilityPkg/Foundation/Efi/Protocol/HiiDatabase/HiiDatabase.h
+++ b/EdkCompatibilityPkg/Foundation/Efi/Protocol/HiiDatabase/HiiDatabase.h
@@ -201,7 +201,7 @@ EFI_STATUS
     Handle             - An array of EFI_HII_HANDLE instances returned.
         
   Returns:
-    EFI_SUCCESS            - The matching handles are outputed successfully.
+    EFI_SUCCESS            - The matching handles are outputted successfully.
                              HandleBufferLength is updated with the actual length.
     EFI_BUFFER_TO_SMALL    - The HandleBufferLength parameter indicates that
                              Handle is too small to support the number of handles.
@@ -248,7 +248,7 @@ EFI_STATUS
                              is too small to support the number of handles.     
                              HandleBufferLength is updated with a value that will
                              enable the data to fit.
-    EFI_NOT_FOUND          - The specifiecd Handle could not be found in the current
+    EFI_NOT_FOUND          - The specified Handle could not be found in the current
                              database.
     EFI_INVALID_PARAMETER  - Handle or Buffer or BufferSize was NULL.
      
diff --git a/EdkCompatibilityPkg/Foundation/Framework/Include/EfiDependency.h b/EdkCompatibilityPkg/Foundation/Framework/Include/EfiDependency.h
index 41dad65..5a14a13 100644
--- a/EdkCompatibilityPkg/Foundation/Framework/Include/EfiDependency.h
+++ b/EdkCompatibilityPkg/Foundation/Framework/Include/EfiDependency.h
@@ -28,8 +28,8 @@ Abstract:
 // EFI_DEP_BEFORE       - If present, it must be the first and only opcode
 // EFI_DEP_AFTER        - If present, it must be the first and only opcode
 // EFI_DEP_SOR          - If present, it must be the first opcode
-// EFI_DEP_REPLACE_TRUE - Used to dynamically patch the dependecy expression
-//                        to save time.  A EFI_DEP_PUSH is evauated one an
+// EFI_DEP_REPLACE_TRUE - Used to dynamically patch the dependency expression
+//                        to save time.  A EFI_DEP_PUSH is evaluated one an
 //                        replaced with EFI_DEP_REPLACE_TRUE
 //
 #define EFI_DEP_BEFORE        0x00
diff --git a/EdkCompatibilityPkg/Foundation/Framework/Protocol/LegacyBios/LegacyBios.h b/EdkCompatibilityPkg/Foundation/Framework/Protocol/LegacyBios/LegacyBios.h
index e2bc450..46ed778 100644
--- a/EdkCompatibilityPkg/Foundation/Framework/Protocol/LegacyBios/LegacyBios.h
+++ b/EdkCompatibilityPkg/Foundation/Framework/Protocol/LegacyBios/LegacyBios.h
@@ -433,7 +433,7 @@ EFI_STATUS
     Flags     - Indicates if ROM found and if PC-AT.
 
   Returns:
-    EFI_SUCCESS  - Legacy Option ROM availible for this device
+    EFI_SUCCESS  - Legacy Option ROM available for this device
     EFI_UNSUPPORTED  - Legacy Option ROM not supported.
 
 --*/
diff --git a/EdkCompatibilityPkg/Foundation/Library/CustomizedDecompress/CustomizedDecompress.c b/EdkCompatibilityPkg/Foundation/Library/CustomizedDecompress/CustomizedDecompress.c
index 03032b9..030dade 100644
--- a/EdkCompatibilityPkg/Foundation/Library/CustomizedDecompress/CustomizedDecompress.c
+++ b/EdkCompatibilityPkg/Foundation/Library/CustomizedDecompress/CustomizedDecompress.c
@@ -74,7 +74,7 @@ Arguments:
 
 Returns:
 
-  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successull retrieved.
+  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successfully retrieved.
   EFI_INVALID_PARAMETER - The source data is corrupted
   EFI_UNSUPPORTED       - Not supported
 
diff --git a/EdkCompatibilityPkg/Foundation/Library/CustomizedDecompress/CustomizedDecompress.h b/EdkCompatibilityPkg/Foundation/Library/CustomizedDecompress/CustomizedDecompress.h
index 701831b..d7ecb23 100644
--- a/EdkCompatibilityPkg/Foundation/Library/CustomizedDecompress/CustomizedDecompress.h
+++ b/EdkCompatibilityPkg/Foundation/Library/CustomizedDecompress/CustomizedDecompress.h
@@ -47,7 +47,7 @@ Arguments:
 
 Returns:
 
-  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successull retrieved.
+  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successfully retrieved.
   EFI_INVALID_PARAMETER - The source data is corrupted
   EFI_UNSUPPORTED       - Not supported
 
diff --git a/EdkCompatibilityPkg/Foundation/Library/Dxe/Include/Ia32/CpuFuncs.h b/EdkCompatibilityPkg/Foundation/Library/Dxe/Include/Ia32/CpuFuncs.h
index 3d1089f..1f5201b 100644
--- a/EdkCompatibilityPkg/Foundation/Library/Dxe/Include/Ia32/CpuFuncs.h
+++ b/EdkCompatibilityPkg/Foundation/Library/Dxe/Include/Ia32/CpuFuncs.h
@@ -182,7 +182,7 @@ EfiCpuid (
                                                                                     
 Routine Description:                                     
            
-  Get the Cpu info by excute the CPUID instruction.
+  Get the Cpu info by execute the CPUID instruction.
   
 Arguments:                
 
diff --git a/EdkCompatibilityPkg/Foundation/Library/Dxe/Include/X64/CpuFuncs.h b/EdkCompatibilityPkg/Foundation/Library/Dxe/Include/X64/CpuFuncs.h
index 99d8a62..567bf37 100644
--- a/EdkCompatibilityPkg/Foundation/Library/Dxe/Include/X64/CpuFuncs.h
+++ b/EdkCompatibilityPkg/Foundation/Library/Dxe/Include/X64/CpuFuncs.h
@@ -184,7 +184,7 @@ EfiCpuid (
                                                                                     
 Routine Description:                                     
            
-  Get the Cpu info by excute the CPUID instruction.
+  Get the Cpu info by execute the CPUID instruction.
   
 Arguments:                
 
diff --git a/EdkCompatibilityPkg/Foundation/Library/Dxe/UefiEfiIfrSupportLib/UefiIfrForm.c b/EdkCompatibilityPkg/Foundation/Library/Dxe/UefiEfiIfrSupportLib/UefiIfrForm.c
index 864a850..366eab8 100644
--- a/EdkCompatibilityPkg/Foundation/Library/Dxe/UefiEfiIfrSupportLib/UefiIfrForm.c
+++ b/EdkCompatibilityPkg/Foundation/Library/Dxe/UefiEfiIfrSupportLib/UefiIfrForm.c
@@ -1641,7 +1641,7 @@ Returns:
   }
 
   //
-  // Retrive formset storage data from Form Browser
+  // Retrieve formset storage data from Form Browser
   //
   ConfigHdr = mFakeConfigHdr;
   HeaderLen = EfiStrLen (ConfigHdr);
diff --git a/EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Include/Library/EdkIIGluePrintLib.h b/EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Include/Library/EdkIIGluePrintLib.h
index 86bd172..54a870e 100644
--- a/EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Include/Library/EdkIIGluePrintLib.h
+++ b/EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Include/Library/EdkIIGluePrintLib.h
@@ -25,7 +25,7 @@ Abstract:
 
 ///
 /// Define the maximum number of characters that are required to
-/// encode a decimal, hexidecimal, GUID, or TIME value with a NULL 
+/// encode a decimal, hexadecimal, GUID, or TIME value with a NULL
 /// terminator.
 ///  
 ///  Maximum Length Decimal String     = 28
diff --git a/EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Include/Library/EdkIIGlueUefiDecompressLib.h b/EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Include/Library/EdkIIGlueUefiDecompressLib.h
index 01a3bdf..8a0d8e1 100644
--- a/EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Include/Library/EdkIIGlueUefiDecompressLib.h
+++ b/EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Include/Library/EdkIIGlueUefiDecompressLib.h
@@ -63,7 +63,7 @@ Abstract:
                           by Source and SourceSize.
 
   @retval  RETURN_SUCCESS The size of destination buffer and the size of scratch 
-                          buffer are successull retrieved.
+                          buffer are successfully retrieved.
   @retval  RETURN_INVALID_PARAMETER The source data is corrupted
 
 **/
diff --git a/EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Library/BaseUefiDecompressLib/BaseUefiDecompressLibInternals.h b/EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Library/BaseUefiDecompressLib/BaseUefiDecompressLibInternals.h
index eb7f20b..cbd8883 100644
--- a/EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Library/BaseUefiDecompressLib/BaseUefiDecompressLibInternals.h
+++ b/EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Library/BaseUefiDecompressLib/BaseUefiDecompressLibInternals.h
@@ -155,7 +155,7 @@ GlueDecodeP (
 /**
   Reads code lengths for the Extra Set or the Position Set.
 
-  Read in the Extra Set or Pointion Set Length Arrary, then
+  Read in the Extra Set or Position Set Length Array, then
   generate the Huffman code mapping for them.
 
   @param  Sd      The global scratch data.
diff --git a/EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Library/DxeIoLibCpuIo/DxeCpuIoLibInternal.h b/EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Library/DxeIoLibCpuIo/DxeCpuIoLibInternal.h
index 881942b..4168cec 100644
--- a/EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Library/DxeIoLibCpuIo/DxeCpuIoLibInternal.h
+++ b/EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Library/DxeIoLibCpuIo/DxeCpuIoLibInternal.h
@@ -58,7 +58,7 @@ IoReadWorker (
   @param  Width         The width of the I/O operation.
   @param  Data          The value to write to the I/O port.
 
-  @return The paramter of Data.
+  @return The parameter of Data.
 
 **/
 UINT64
diff --git a/EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Library/DxeIoLibCpuIo/IoLib.c b/EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Library/DxeIoLibCpuIo/IoLib.c
index ce8d07b..b002852 100644
--- a/EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Library/DxeIoLibCpuIo/IoLib.c
+++ b/EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Library/DxeIoLibCpuIo/IoLib.c
@@ -96,7 +96,7 @@ IoReadWorker (
   @param  Width         The width of the I/O operation.
   @param  Data          The value to write to the I/O port.
 
-  @return The paramter of Data.
+  @return The parameter of Data.
 
 **/
 UINT64
diff --git a/EdkCompatibilityPkg/Foundation/Library/Pei/PeiLib/Decompress.c b/EdkCompatibilityPkg/Foundation/Library/Pei/PeiLib/Decompress.c
index 6d09c61..5956919 100644
--- a/EdkCompatibilityPkg/Foundation/Library/Pei/PeiLib/Decompress.c
+++ b/EdkCompatibilityPkg/Foundation/Library/Pei/PeiLib/Decompress.c
@@ -825,7 +825,7 @@ Arguments:
 
 Returns:
 
-  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successull retrieved.
+  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successfully retrieved.
   EFI_INVALID_PARAMETER - The source data is corrupted
 
 --*/
@@ -994,7 +994,7 @@ Arguments:
 
 Returns:
 
-  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successull retrieved.
+  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successfully retrieved.
   EFI_INVALID_PARAMETER - The source data is corrupted
 
 --*/
@@ -1080,7 +1080,7 @@ Arguments:
 
 Returns:
 
-  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successull retrieved.
+  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successfully retrieved.
   EFI_INVALID_PARAMETER - The source data is corrupted
 
 --*/
diff --git a/EdkCompatibilityPkg/Sample/Platform/Nt32/Ppi/NtAutoScan/NtAutoScan.h b/EdkCompatibilityPkg/Sample/Platform/Nt32/Ppi/NtAutoScan/NtAutoScan.h
index 5c20db2..6c659e8 100644
--- a/EdkCompatibilityPkg/Sample/Platform/Nt32/Ppi/NtAutoScan/NtAutoScan.h
+++ b/EdkCompatibilityPkg/Sample/Platform/Nt32/Ppi/NtAutoScan/NtAutoScan.h
@@ -42,7 +42,7 @@ EFI_STATUS
 
 Routine Description:
   This service is called from Index == 0 until it returns EFI_UNSUPPORTED.
-  It allows discontiguous memory regions to be supported by the emulator.
+  It allows discontinuous memory regions to be supported by the emulator.
   It uses gSystemMemory[] and gSystemMemoryCount that were created by
   parsing the Windows environment variable EFI_MEMORY_SIZE.
   The size comes from the varaible and the address comes from the call to
diff --git a/EdkCompatibilityPkg/Sample/Tools/Source/Common/Decompress.c b/EdkCompatibilityPkg/Sample/Tools/Source/Common/Decompress.c
index 3f05bda..bdfe500 100644
--- a/EdkCompatibilityPkg/Sample/Tools/Source/Common/Decompress.c
+++ b/EdkCompatibilityPkg/Sample/Tools/Source/Common/Decompress.c
@@ -681,7 +681,7 @@ Arguments:
 
 Returns:
 
-  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successull retrieved.
+  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successfully retrieved.
   EFI_INVALID_PARAMETER - The source data is corrupted
 
 --*/
@@ -849,7 +849,7 @@ Arguments:
 
 Returns:
 
-  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successull retrieved.
+  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successfully retrieved.
   EFI_INVALID_PARAMETER - The source data is corrupted
 
 --*/
@@ -933,7 +933,7 @@ Arguments:
 
 Returns:
 
-  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successull retrieved.
+  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successfully retrieved.
   EFI_INVALID_PARAMETER - The source data is corrupted
 
 --*/
diff --git a/EdkCompatibilityPkg/Sample/Tools/Source/Common/Decompress.h b/EdkCompatibilityPkg/Sample/Tools/Source/Common/Decompress.h
index 50458ef..ca1cd90 100644
--- a/EdkCompatibilityPkg/Sample/Tools/Source/Common/Decompress.h
+++ b/EdkCompatibilityPkg/Sample/Tools/Source/Common/Decompress.h
@@ -47,7 +47,7 @@ Arguments:
 
 Returns:
 
-  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successull retrieved.
+  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successfully retrieved.
   EFI_INVALID_PARAMETER - The source data is corrupted
 
 --*/
@@ -111,7 +111,7 @@ Arguments:
 
 Returns:
 
-  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successull retrieved.
+  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successfully retrieved.
   EFI_INVALID_PARAMETER - The source data is corrupted
 
 --*/
diff --git a/EdkCompatibilityPkg/Sample/Tools/Source/Common/EfiCustomizedCompress.h b/EdkCompatibilityPkg/Sample/Tools/Source/Common/EfiCustomizedCompress.h
index 74cbf06..c75d549 100644
--- a/EdkCompatibilityPkg/Sample/Tools/Source/Common/EfiCustomizedCompress.h
+++ b/EdkCompatibilityPkg/Sample/Tools/Source/Common/EfiCustomizedCompress.h
@@ -65,7 +65,7 @@ Arguments:
 
 Returns:
 
-  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successull retrieved.
+  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successfully retrieved.
   EFI_INVALID_PARAMETER - The source data is corrupted
 
 --*/
diff --git a/EdkCompatibilityPkg/Sample/Tools/Source/CustomizedCompress/CustomizedCompress.c b/EdkCompatibilityPkg/Sample/Tools/Source/CustomizedCompress/CustomizedCompress.c
index a336178..c0f6fab 100644
--- a/EdkCompatibilityPkg/Sample/Tools/Source/CustomizedCompress/CustomizedCompress.c
+++ b/EdkCompatibilityPkg/Sample/Tools/Source/CustomizedCompress/CustomizedCompress.c
@@ -66,7 +66,7 @@ Arguments:
     
 Returns:
     
-  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successull retrieved.
+  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successfully retrieved.
   EFI_INVALID_PARAMETER - The source data is corrupted
   EFI_UNSUPPORTED       - The operation is unsupported.
 
diff --git a/EdkCompatibilityPkg/Sample/Tools/Source/GenDepex/GenDepex.c b/EdkCompatibilityPkg/Sample/Tools/Source/GenDepex/GenDepex.c
index 2cfc307..5d7f693 100644
--- a/EdkCompatibilityPkg/Sample/Tools/Source/GenDepex/GenDepex.c
+++ b/EdkCompatibilityPkg/Sample/Tools/Source/GenDepex/GenDepex.c
@@ -266,7 +266,7 @@ Routine Description:
     <boolval> ::= true | 
                   false
 
-  The outputed binary grammer is thus:
+  The outputted binary grammer is thus:
     <depex> ::= sor <dep> | 
                 before <depinst> <dep> | 
                 after <depinst> <dep> | 
diff --git a/EdkCompatibilityPkg/Sample/Tools/Source/GenFfsFile/GenFfsFile.c b/EdkCompatibilityPkg/Sample/Tools/Source/GenFfsFile/GenFfsFile.c
index 269a5b8..f84f152 100644
--- a/EdkCompatibilityPkg/Sample/Tools/Source/GenFfsFile/GenFfsFile.c
+++ b/EdkCompatibilityPkg/Sample/Tools/Source/GenFfsFile/GenFfsFile.c
@@ -644,7 +644,7 @@ Returns:
 
   } else if (_strcmpi (Type, "LZH") == 0) {
     //
-    // EFI stardard compression (LZH)
+    // EFI standard compression (LZH)
     //
     CompressionType   = EFI_STANDARD_COMPRESSION;
     CompressFunction  = (COMPRESS_FUNCTION) TianoCompress;
diff --git a/EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Library/BaseUefiDecompressLib/BaseUefiDecompressLib.c b/EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Library/BaseUefiDecompressLib/BaseUefiDecompressLib.c
index a57b0b9..819e5f1 100644
--- a/EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Library/BaseUefiDecompressLib/BaseUefiDecompressLib.c
+++ b/EdkCompatibilityPkg/Foundation/Library/EdkIIGlueLib/Library/BaseUefiDecompressLib/BaseUefiDecompressLib.c
@@ -321,7 +321,7 @@ GlueDecodeP (
 /**
   Reads code lengths for the Extra Set or the Position Set.
 
-  Read in the Extra Set or Pointion Set Length Arrary, then
+  Read in the Extra Set or Position Set Length Array, then
   generate the Huffman code mapping for them.
 
   @param  Sd      The global scratch data.
@@ -544,7 +544,7 @@ GlueDecodeC (
     Sd->mBlockSize    = (UINT16) GetBits (Sd, 16);
 
     //
     // Read in the Extra Set Code Length Arrary,
     // Generate the Huffman code mapping table for Extra Set.
     //
     Sd->mBadTableFlag = ReadPTLen (Sd, NT, TBIT, 3);
@@ -553,13 +553,13 @@ GlueDecodeC (
     }
 
     //
     // Read in and decode the Char&Len Set Code Length Arrary,
     // Generate the Huffman code mapping table for Char&Len Set.
     //
     ReadCLen (Sd);
 
     //
     // Read in the Position Set Code Length Arrary, 
     // Generate the Huffman code mapping table for the Position Set.
     //
     Sd->mBadTableFlag = ReadPTLen (Sd, MAXNP, Sd->mPBit, (UINT16) (-1));
@@ -702,7 +702,7 @@ Done:
                           by Source and SourceSize.
 
   @retval  RETURN_SUCCESS The size of destination buffer and the size of scratch 
-                          buffer are successull retrieved.
+                          buffer are successfully retrieved.
   @retval  RETURN_INVALID_PARAMETER The source data is corrupted
 
 **/
@@ -544,7 +544,7 @@ GlueDecodeC (
 
     //
-    // Read in the Extra Set Code Length Arrary,
+    // Read in the Extra Set Code Length Array,
     // Generate the Huffman code mapping table for Extra Set.
     //
@@ -553,13 +553,13 @@ GlueDecodeC (
 
     //
-    // Read in and decode the Char&Len Set Code Length Arrary,
+    // Read in and decode the Char&Len Set Code Length Array,
     // Generate the Huffman code mapping table for Char&Len Set.
     //
@@ -553,13 +553,13 @@ GlueDecodeC (
 
     //
-    // Read in the Position Set Code Length Arrary, 
+    // Read in the Position Set Code Length Array,
     // Generate the Huffman code mapping table for the Position Set.
     //
-- 
2.10.1



  parent reply	other threads:[~2016-10-19  7:02 UTC|newest]

Thread overview: 79+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2016-10-19  7:01 [PATCH 00/33] Fix typos in comments and variables Gary Lin
2016-10-19  7:01 ` [PATCH 01/33] ArmPkg: Fix typos in comments Gary Lin
2016-10-19 15:09   ` Ard Biesheuvel
2016-10-19 15:15     ` Laszlo Ersek
2016-10-19 15:33       ` Leif Lindholm
2016-10-19  7:01 ` [PATCH 02/33] BaseTools: Fix typos in comments and variables Gary Lin
2016-10-19  7:30   ` Gao, Liming
2016-10-19  7:36   ` Zhu, Yonghong
2016-10-19  7:01 ` [PATCH 03/33] CorebootPayloadPkg: Fix typos in comments Gary Lin
2016-10-26 18:50   ` Ma, Maurice
2016-10-19  7:01 ` [PATCH 04/33] CorebootModulePkg: " Gary Lin
2016-10-26 18:41   ` Ma, Maurice
2016-10-19  7:01 ` [PATCH 05/33] CryptoPkg: " Gary Lin
2016-10-26  3:00   ` Long, Qin
2016-10-19  7:01 ` [PATCH 06/33] DuetPkg: " Gary Lin
2016-10-19  7:46   ` Ni, Ruiyu
2016-10-19  7:01 ` Gary Lin [this message]
2016-10-19  8:19   ` [PATCH 07/33] EdkCompatibilityPkg: " Gao, Liming
2016-10-19  7:01 ` [PATCH 08/33] EmulatorPkg: Fix typos in comments and variables Gary Lin
2016-10-19 20:37   ` Jordan Justen
2016-10-20  8:16     ` Laszlo Ersek
2016-10-19  7:01 ` [PATCH 09/33] EmbeddedPkg: Fix typos in comments Gary Lin
2016-10-19 15:09   ` Ard Biesheuvel
2016-10-19  7:01 ` [PATCH 10/33] IntelFrameworkModulePkg: " Gary Lin
2016-10-20  1:08   ` Fan, Jeff
2016-10-19  7:01 ` [PATCH 11/33] IntelFrameworkPkg: " Gary Lin
2016-10-20  1:08   ` Fan, Jeff
2016-10-19  7:01 ` [PATCH 12/33] IntelFspPkg: " Gary Lin
2016-10-19  7:06   ` Yao, Jiewen
2016-10-19  7:01 ` [PATCH 13/33] IntelFspWrapperPkg: " Gary Lin
2016-10-19  7:08   ` Yao, Jiewen
2016-10-19  7:01 ` [PATCH 14/33] IntelFsp2Pkg: " Gary Lin
2016-10-19  7:06   ` Yao, Jiewen
2016-10-19  7:12   ` Mudusuru, Giri P
2016-10-19  7:01 ` [PATCH 15/33] IntelFsp2WrapperPkg: Fix a typo in the comment Gary Lin
2016-10-19  7:07   ` Yao, Jiewen
2016-10-19  7:11   ` Mudusuru, Giri P
2016-10-19  7:01 ` [PATCH 16/33] MdeModulePkg: BootManagerMenuApp: Fix typos in comments Gary Lin
2016-10-19  8:20   ` Tian, Feng
2016-10-19  7:01 ` [PATCH 17/33] MdeModulePkg/Bus: " Gary Lin
2016-10-19  7:01 ` [PATCH 18/33] MdeModulePkg/Core: " Gary Lin
2016-10-19  8:20   ` Tian, Feng
2016-10-19  7:01 ` [PATCH 19/33] MdeModulePkg/Include: " Gary Lin
2016-10-19  7:01 ` [PATCH 20/33] MdeModulePkg/Library: Fix typos in comments and variables Gary Lin
2016-10-19  7:01 ` [PATCH 21/33] MdeModulePkg/Universal: Fix typos in comments Gary Lin
2016-10-19  7:01 ` [PATCH 22/33] MdePkg: " Gary Lin
2016-10-19  8:21   ` Gao, Liming
2016-10-19  7:01 ` [PATCH 23/33] NetworkPkg: " Gary Lin
2016-10-19  7:21   ` Fu, Siyuan
2016-10-26  0:53   ` Fu, Siyuan
2016-10-19  7:01 ` [PATCH 24/33] Nt32Pkg: Fix typos in comments and variables Gary Lin
2016-10-19  7:50   ` Ni, Ruiyu
2016-10-19  7:01 ` [PATCH 25/33] OptionRomPkg: Fix typos in comments Gary Lin
2016-10-19  7:51   ` Ni, Ruiyu
2016-10-19  7:01 ` [PATCH 26/33] OvmfPkg: " Gary Lin
2016-10-19  7:01 ` [PATCH 27/33] QuarkPlatformPkg: " Gary Lin
2016-10-25 20:53   ` Kinney, Michael D
2016-10-19  7:01 ` [PATCH 28/33] QuarkSocPkg: " Gary Lin
2016-10-25 21:00   ` Kinney, Michael D
2016-10-19  7:01 ` [PATCH 29/33] SecurityPkg: " Gary Lin
2016-10-27  1:29   ` Zhang, Chao B
2016-11-14  3:12   ` Zhang, Chao B
2016-11-14  4:03     ` Gary Lin
2016-11-14  6:24       ` Gao, Liming
2016-11-14  8:30         ` Gary Lin
2016-10-19  7:01 ` [PATCH 30/33] ShellPkg: Fix typos in comments and variables Gary Lin
2016-10-19  7:51   ` Ni, Ruiyu
2016-10-19 20:29     ` Carsey, Jaben
2016-10-20  1:55       ` Gary Lin
2016-10-19  7:01 ` [PATCH 31/33] SourceLevelDebugPkg: Fix typos in comments Gary Lin
2016-10-19  7:46   ` Wu, Hao A
2016-10-19  7:01 ` [PATCH 32/33] UefiCpuPkg: " Gary Lin
2016-10-20  1:58   ` Fan, Jeff
2016-10-20  2:08     ` Gary Lin
2016-10-20  2:45       ` Fan, Jeff
2016-10-19  7:01 ` [PATCH 33/33] Vlv2TbltDevicePkg: " Gary Lin
2016-10-24  1:33   ` Wei, David
2016-10-19  7:28 ` [PATCH 00/33] Fix typos in comments and variables Zeng, Star
2016-10-19 14:50 ` Leif Lindholm

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-list from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20161019070138.16424-8-glin@suse.com \
    --to=devel@edk2.groups.io \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox